==> viam_sdk-0.2.0-py3-none-macosx_10_16_x86_64.whl: viam/components/gantry/gantry.py <==
import abc
from typing import Any, Dict, List, Optional

from viam.errors import NotSupportedError
from viam.proto.common import WorldState

from ..component_base import ComponentBase


class Gantry(ComponentBase):
    """
    Gantry represents a physical Gantry and can be used for controlling gantries of N axes.

    This acts as an abstract base class for any drivers representing specific
    gantry implementations. This cannot be used on its own. If the `__init__()` function is
    overridden, it must call the `super().__init__()` function.
    """

    @abc.abstractmethod
    async def get_position(self, *, extra: Optional[Dict[str, Any]] = None, timeout: Optional[float] = None, **kwargs) -> List[float]:
        """
        Get the position in millimeters.

        Returns:
            List[float]: The position of the axes.
        """
        ...

    @abc.abstractmethod
    async def move_to_position(
        self,
        positions: List[float],
        world_state: Optional[WorldState] = None,
        *,
        extra: Optional[Dict[str, Any]] = None,
        timeout: Optional[float] = None,
        **kwargs,
    ):
        """
        Move the gantry to a new position.

        Args:
            positions (List[float]): List of positions for the axes to move to,
                in millimeters.
            world_state (Optional[WorldState]): Object describing
                obstacles for the gantry to avoid on its way to `positions`.
        """
        ...

    @abc.abstractmethod
    async def get_lengths(self, *, extra: Optional[Dict[str, Any]] = None, timeout: Optional[float] = None, **kwargs) -> List[float]:
        """
        Get the lengths of the axes of the gantry in millimeters.

        Returns:
            List[float]: The lengths of the axes.
        """
        ...

    @abc.abstractmethod
    async def stop(self, *, extra: Optional[Dict[str, Any]] = None, timeout: Optional[float] = None, **kwargs):
        """
        Stop all motion of the gantry. It is assumed that the gantry stops immediately.
        """
        ...

    async def is_moving(self) -> bool:
        """
        Get if the gantry is currently moving.

        Returns:
            bool: Whether the gantry is moving.
        """
        raise NotSupportedError(f"Gantry named {self.name} does not support returning whether it is moving")

==> viam_sdk-0.4.8-py3-none-macosx_10_16_x86_64.whl: viam/components/gantry/gantry.py <==
import abc
from typing import Any, Dict, Final, List, Optional

from viam.resource.types import RESOURCE_NAMESPACE_RDK, RESOURCE_TYPE_COMPONENT, Subtype

from ..component_base import ComponentBase
from . import Geometry


class Gantry(ComponentBase):
    """
    Gantry represents a physical Gantry and can be used for controlling gantries of N axes.

    This acts as an abstract base class for any drivers representing specific
    gantry implementations. This cannot be used on its own. If the ``__init__()`` function is
    overridden, it must call the ``super().__init__()`` function.
    """

    SUBTYPE: Final = Subtype(RESOURCE_NAMESPACE_RDK, RESOURCE_TYPE_COMPONENT, "gantry")

    @abc.abstractmethod
    async def get_position(self, *, extra: Optional[Dict[str, Any]] = None, timeout: Optional[float] = None, **kwargs) -> List[float]:
        """
        Get the position in millimeters.

        Returns:
            List[float]: The position of the axes.
        """
        ...

    @abc.abstractmethod
    async def move_to_position(
        self,
        positions: List[float],
        speeds: List[float],
        *,
        extra: Optional[Dict[str, Any]] = None,
        timeout: Optional[float] = None,
        **kwargs,
    ):
        """
        Move the gantry to a new position at the requested speeds.

        Args:
            positions (List[float]): List of positions for the axes to move to,
                in millimeters.
        """
        ...

    @abc.abstractmethod
    async def home(self, *, extra: Optional[Dict[str, Any]] = None, timeout: Optional[float] = None, **kwargs) -> bool:
        """
        Home the gantry to find it's starting and ending positions

        Returns:
            bool : whether the gantry has run the homing sequence successfully
        """

    @abc.abstractmethod
    async def get_lengths(self, *, extra: Optional[Dict[str, Any]] = None, timeout: Optional[float] = None, **kwargs) -> List[float]:
        """
        Get the lengths of the axes of the gantry in millimeters.

        Returns:
            List[float]: The lengths of the axes.
        """
        ...

    @abc.abstractmethod
    async def stop(self, *, extra: Optional[Dict[str, Any]] = None, timeout: Optional[float] = None, **kwargs):
        """
        Stop all motion of the gantry. It is assumed that the gantry stops immediately.
        """
        ...

    @abc.abstractmethod
    async def is_moving(self) -> bool:
        """
        Get if the gantry is currently moving.

        Returns:
            bool: Whether the gantry is moving.
        """
        ...

    @abc.abstractmethod
    async def get_geometries(self) -> List[Geometry]:
        """
        Get all geometries associated with the gantry, in their current configuration, in the frame of the gantry.

        Returns:
            List[Geometry]: The geometries associated with the gantry.
        """
        ...
